@@ -1,6 +1,9 @@
-import unittest, os
+import unittest
+import os
 from shutil import rmtree
 
+import pytest
+
 from vespa.package import (
     HNSW,
     Field,
@@ -64,14 +67,14 @@ class TestField(unittest.TestCase):
         self.assertEqual(field, Field.from_dict(field.to_dict))
         self.assertEqual(field.indexing_to_text, "index | summary")
 
-    def test_tensor_with_hsnw(self):
+    def test_tensor_with_hnsw(self):
         field = Field(
             name="tensor_field",
             type="tensor<float>(x[128])",
             indexing=["attribute"],
             attribute=["fast-search", "fast-access"],
             ann=HNSW(
-                distance_metric="enclidean",
+                distance_metric="euclidean",
                 max_links_per_node=16,
                 neighbors_to_explore_at_insert=200,
             ),
@@ -613,7 +616,7 @@ class TestApplicationPackage(unittest.TestCase):
             ]
         )
         self.app_package = ApplicationPackage(
-            name="test_app",
+            name="testapp",
             schema=[self.test_schema],
             query_profile=test_query_profile,
             query_profile_type=test_query_profile_type,
@@ -738,27 +741,15 @@ class TestApplicationPackage(unittest.TestCase):
         )
         self.assertEqual(self.app_package.schema.schema_to_text, expected_result)
 
-    def test_hosts_to_text(self):
-        expected_result = (
-            '<?xml version="1.0" encoding="utf-8" ?>\n'
-            "<!-- Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root. -->\n"
-            "<hosts>\n"
-            '    <host name="localhost">\n'
-            "        <alias>node1</alias>\n"
-            "    </host>\n"
-            "</hosts>"
-        )
-        self.assertEqual(self.app_package.hosts_to_text, expected_result)
-
     def test_services_to_text(self):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_app_container" version="1.0">\n'
+            '    <container id="testapp_container" version="1.0">\n'
             "        <search></search>\n"
             "        <document-api></document-api>\n"
             "    </container>\n"
-            '    <content id="test_app_content" version="1.0">\n'
+            '    <content id="testapp_content" version="1.0">\n'
             '        <redundancy reply-after="1">1</redundancy>\n'
             "        <documents>\n"
             '            <document type="msmarco" mode="index"></document>\n'
@@ -840,7 +831,7 @@ class TestApplicationPackageMultipleSchema(unittest.TestCase):
             ),
         )
         self.app_package = ApplicationPackage(
-            name="test_app",
+            name="testapp",
             schema=[self.news_schema, self.user_schema, self.category_ctr_schema],
         )
 
@@ -907,11 +898,11 @@ class TestApplicationPackageMultipleSchema(unittest.TestCase):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_app_container" version="1.0">\n'
+            '    <container id="testapp_container" version="1.0">\n'
             "        <search></search>\n"
             "        <document-api></document-api>\n"
             "    </container>\n"
-            '    <content id="test_app_content" version="1.0">\n'
+            '    <content id="testapp_content" version="1.0">\n'
             '        <redundancy reply-after="1">1</redundancy>\n'
             "        <documents>\n"
             '            <document type="news" mode="index"></document>\n'
@@ -951,7 +942,7 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
             ),
         )
         self.app_package = ApplicationPackage(
-            name="test_app",
+            name="testapp",
             schema=[news_schema, user_schema],
         )
         bert_config = BertModelConfig(
@@ -1071,27 +1062,15 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
             self.app_package.get_schema("user").schema_to_text, expected_user_result
         )
 
-    def test_hosts_to_text(self):
-        expected_result = (
-            '<?xml version="1.0" encoding="utf-8" ?>\n'
-            "<!-- Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root. -->\n"
-            "<hosts>\n"
-            '    <host name="localhost">\n'
-            "        <alias>node1</alias>\n"
-            "    </host>\n"
-            "</hosts>"
-        )
-        self.assertEqual(self.app_package.hosts_to_text, expected_result)
-
     def test_services_to_text(self):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_app_container" version="1.0">\n'
+            '    <container id="testapp_container" version="1.0">\n'
             "        <search></search>\n"
             "        <document-api></document-api>\n"
             "    </container>\n"
-            '    <content id="test_app_content" version="1.0">\n'
+            '    <content id="testapp_content" version="1.0">\n'
             '        <redundancy reply-after="1">1</redundancy>\n'
             "        <documents>\n"
             '            <document type="news" mode="index"></document>\n'
@@ -1133,7 +1112,7 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
 
 class TestSimplifiedApplicationPackage(unittest.TestCase):
     def setUp(self) -> None:
-        self.app_package = ApplicationPackage(name="test_app")
+        self.app_package = ApplicationPackage(name="testapp")
 
         self.app_package.schema.add_fields(
             Field(name="id", type="string", indexing=["attribute", "summary"]),
@@ -1192,8 +1171,8 @@ class TestSimplifiedApplicationPackage(unittest.TestCase):
 
     def test_schema_to_text(self):
         expected_result = (
-            "schema test_app {\n"
-            "    document test_app {\n"
+            "schema testapp {\n"
+            "    document testapp {\n"
             "        field id type string {\n"
             "            indexing: attribute | summary\n"
             "        }\n"
@@ -1237,30 +1216,18 @@ class TestSimplifiedApplicationPackage(unittest.TestCase):
         )
         self.assertEqual(self.app_package.schema.schema_to_text, expected_result)
 
-    def test_hosts_to_text(self):
-        expected_result = (
-            '<?xml version="1.0" encoding="utf-8" ?>\n'
-            "<!-- Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root. -->\n"
-            "<hosts>\n"
-            '    <host name="localhost">\n'
-            "        <alias>node1</alias>\n"
-            "    </host>\n"
-            "</hosts>"
-        )
-        self.assertEqual(self.app_package.hosts_to_text, expected_result)
-
     def test_services_to_text(self):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_app_container" version="1.0">\n'
+            '    <container id="testapp_container" version="1.0">\n'
             "        <search></search>\n"
             "        <document-api></document-api>\n"
             "    </container>\n"
-            '    <content id="test_app_content" version="1.0">\n'
+            '    <content id="testapp_content" version="1.0">\n'
             '        <redundancy reply-after="1">1</redundancy>\n'
             "        <documents>\n"
-            '            <document type="test_app" mode="index"></document>\n'
+            '            <document type="testapp" mode="index"></document>\n'
             "        </documents>\n"
             "        <nodes>\n"
             '            <node distribution-key="0" hostalias="node1"></node>\n'
@@ -1366,7 +1333,7 @@ class TestSimplifiedApplicationPackageWithMultipleSchemas(unittest.TestCase):
 
 class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
     def setUp(self) -> None:
-        self.app_package = ApplicationPackage(name="test_app")
+        self.app_package = ApplicationPackage(name="testapp")
 
         self.app_package.schema.add_fields(
             Field(name="id", type="string", indexing=["attribute", "summary"]),
@@ -1431,8 +1398,8 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
 
     def test_schema_to_text(self):
         expected_result = (
-            "schema test_app {\n"
-            "    document test_app {\n"
+            "schema testapp {\n"
+            "    document testapp {\n"
             "        field id type string {\n"
             "            indexing: attribute | summary\n"
             "        }\n"
@@ -1528,30 +1495,18 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
         )
         self.assertEqual(self.app_package.schema.schema_to_text, expected_result)
 
-    def test_hosts_to_text(self):
-        expected_result = (
-            '<?xml version="1.0" encoding="utf-8" ?>\n'
-            "<!-- Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root. -->\n"
-            "<hosts>\n"
-            '    <host name="localhost">\n'
-            "        <alias>node1</alias>\n"
-            "    </host>\n"
-            "</hosts>"
-        )
-        self.assertEqual(self.app_package.hosts_to_text, expected_result)
-
     def test_services_to_text(self):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_app_container" version="1.0">\n'
+            '    <container id="testapp_container" version="1.0">\n'
             "        <search></search>\n"
             "        <document-api></document-api>\n"
             "    </container>\n"
-            '    <content id="test_app_content" version="1.0">\n'
+            '    <content id="testapp_content" version="1.0">\n'
             '        <redundancy reply-after="1">1</redundancy>\n'
             "        <documents>\n"
-            '            <document type="test_app" mode="index"></document>\n'
+            '            <document type="testapp" mode="index"></document>\n'
             "        </documents>\n"
             "        <nodes>\n"
             '            <node distribution-key="0" hostalias="node1"></node>\n'
@@ -1591,9 +1546,18 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
         rmtree(self.disk_folder, ignore_errors=True)
 
 
+class TestValidAppName(unittest.TestCase):
+
+    def test_invalid_name(self):
+        with pytest.raises(ValueError):
+            app_package = ApplicationPackage(name="test_app")
+        with pytest.raises(ValueError):
+            app_package = ApplicationPackage(name="test-app")
+
+
 class TestModelServer(unittest.TestCase):
     def setUp(self) -> None:
-        self.server_name = "test_server"
+        self.server_name = "testserver"
         self.model_server = ModelServer(
             name=self.server_name,
         )
@@ -1607,23 +1571,11 @@ class TestModelServer(unittest.TestCase):
         self.assertIsNone(self.model_server.schema)
         self.assertEqual(self.model_server.schema, self.model_server.get_schema())
 
-    def test_hosts_to_text(self):
-        expected_result = (
-            '<?xml version="1.0" encoding="utf-8" ?>\n'
-            "<!-- Copyright 2019 Oath Inc. Licensed under the terms of the Apache 2.0 license. See LICENSE in the project root. -->\n"
-            "<hosts>\n"
-            '    <host name="localhost">\n'
-            "        <alias>node1</alias>\n"
-            "    </host>\n"
-            "</hosts>"
-        )
-        self.assertEqual(self.model_server.hosts_to_text, expected_result)
-
     def test_services_to_text(self):
         expected_result = (
             '<?xml version="1.0" encoding="UTF-8"?>\n'
             '<services version="1.0">\n'
-            '    <container id="test_server_container" version="1.0">\n'
+            '    <container id="testserver_container" version="1.0">\n'
             "        <model-evaluation/>\n"
             "    </container>\n"
             "</services>"
